#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_CUMPROD_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_CUMPROD_HPP_INCLUDED

#include <boost/simd/swar/include/functions/cumprod.hpp>

#endif
